'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var runtimeCore = require('@vue/runtime-core');
var index = require('../virtual-list/index.js');
var utils = require('./utils.js');

const optionListProps = {
  prefixCls: String,
  options: Array,
  values: Set,
  height: {
    type: Number,
    default: 500
  },
  virtualScroll: Boolean
};
var OptionList = vue.defineComponent({
  name: "x-option-list",
  props: optionListProps,
  slots: ["label"],
  emits: ["click", "select"],
  setup(props, {
    attrs,
    emit,
    slots
  }) {
    const {
      prefixCls
    } = props;
    const optionPrefixCls = `${prefixCls}-option`;
    function onClick(option) {
      emit("click", option);
      emit("select", option);
    }
    const item = (...args) => {
      var _a;
      const {
        item: option,
        index
      } = args[0];
      let label = (_a = slots.default) == null ? void 0 : _a.call(slots, ...args);
      if (label === void 0)
        label = utils.getLabel(option);
      if (slots.label)
        label = slots.label({
          option,
          label,
          index
        });
      const selected = props.values.has(option.value);
      let itemProps = {
        class: [optionPrefixCls, {
          selected,
          [`${optionPrefixCls}-selected`]: selected,
          [`${optionPrefixCls}-disabled`]: option.disabled
        }],
        onClick: () => onClick(option)
      };
      itemProps = runtimeCore.mergeProps(itemProps, option);
      return vue.createVNode("div", itemProps, [vue.createVNode("div", {
        "class": `${optionPrefixCls}-content`
      }, [label])]);
    };
    return () => {
      const slots2 = {
        default: item
      };
      return vue.createVNode(index, {
        "virtual": props.virtualScroll,
        "data": props.options,
        "height": props.height,
        "itemKey": "value"
      }, slots2);
    };
  }
});

exports["default"] = OptionList;
exports.optionListProps = optionListProps;
