'use strict';

var vue = require('vue');
var index = require('../../tag/index.js');

function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !vue.isVNode(s);
}
var Selector = vue.defineComponent({
  name: "Selector",
  props: {
    prefixCls: String,
    values: Array,
    searchValue: String,
    multiple: Boolean,
    showArrow: Boolean,
    filterable: Boolean,
    clearable: Boolean,
    disabled: Boolean,
    placeholder: String,
    inputRef: {
      default: () => vue.ref()
    },
    onSelect: Function,
    onSearch: Function,
    onToggleOpen: Function,
    onFocus: Function,
    onBlur: Function
  },
  setup(props) {
    const hasTextInput = vue.computed(() => {
      var _a;
      return !!((_a = props.values) == null ? void 0 : _a.length) || !!props.searchValue;
    });
    function getLabel(item) {
      if (!item)
        return item;
      let content;
      if (content === void 0)
        content = item.label;
      if (content === void 0)
        content = item.value;
      if (content === void 0)
        content = item;
      return content;
    }
    function onSelect(item) {
      var _a;
      (_a = props.onSelect) == null ? void 0 : _a.call(props, item);
    }
    function onClick() {
      props.inputRef.value.focus();
    }
    function onMousedown() {
      props.onToggleOpen();
    }
    function onInputChange(e) {
      props.onToggleOpen(true);
      props.onSearch(e.target.value);
    }
    return () => {
      const {
        prefixCls,
        values = [],
        multiple
      } = props;
      const inputProps = {
        class: `${prefixCls}_search_input`,
        ref: props.inputRef,
        value: props.searchValue,
        disabled: props.disabled || !props.filterable && !props.multiple,
        placeholder: !values.length ? props.placeholder : void 0,
        onInput: onInputChange,
        onFocus: props.onFocus,
        onBlur: props.onBlur
      };
      const tagsNode = multiple ? values.map((e) => {
        let _slot;
        return vue.createVNode(index, {
          "class": `${prefixCls}_tag`,
          "closable": !props.disabled,
          "onClose": () => onSelect(e)
        }, _isSlot(_slot = getLabel(e)) ? _slot : {
          default: () => [_slot]
        });
      }) : void 0;
      const textNode = vue.createVNode("span", {
        "class": `${prefixCls}_text`
      }, [!multiple && !props.searchValue ? getLabel(values[0]) : " "]);
      return vue.createVNode("div", {
        "class": `${prefixCls}_selector`,
        "onClick": onClick,
        "onMousedown": onMousedown
      }, [tagsNode, vue.createVNode("div", {
        "class": `${prefixCls}_search`
      }, [vue.createVNode("input", inputProps, null)]), textNode]);
    };
  }
});

module.exports = Selector;
