import { defineComponent, createVNode } from 'vue';
import { mergeProps } from '@vue/runtime-core';
import VirtualList from '../virtual-list/index.js';
import { getLabel } from './utils.js';

const optionListProps = {
  prefixCls: String,
  options: Array,
  values: Set,
  height: {
    type: Number,
    default: 500
  },
  virtualScroll: Boolean
};
var OptionList = defineComponent({
  name: "x-option-list",
  props: optionListProps,
  slots: ["label"],
  emits: ["click", "select"],
  setup(props, {
    attrs,
    emit,
    slots
  }) {
    const {
      prefixCls
    } = props;
    const optionPrefixCls = `${prefixCls}-option`;
    function onClick(option) {
      emit("click", option);
      emit("select", option);
    }
    const item = (...args) => {
      var _a;
      const {
        item: option,
        index
      } = args[0];
      let label = (_a = slots.default) == null ? void 0 : _a.call(slots, ...args);
      if (label === void 0)
        label = getLabel(option);
      if (slots.label)
        label = slots.label({
          option,
          label,
          index
        });
      const selected = props.values.has(option.value);
      let itemProps = {
        class: [optionPrefixCls, {
          selected,
          [`${optionPrefixCls}-selected`]: selected,
          [`${optionPrefixCls}-disabled`]: option.disabled
        }],
        onClick: () => onClick(option)
      };
      itemProps = mergeProps(itemProps, option);
      return createVNode("div", itemProps, [createVNode("div", {
        "class": `${optionPrefixCls}-content`
      }, [label])]);
    };
    return () => {
      const slots2 = {
        default: item
      };
      return createVNode(VirtualList, {
        "virtual": props.virtualScroll,
        "data": props.options,
        "height": props.height,
        "itemKey": "value"
      }, slots2);
    };
  }
});

export { OptionList as default, optionListProps };
